#line 2 "llsphinxql.c"

#line 4 "llsphinxql.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin ,yyscanner )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart (FILE *input_file ,yyscan_t yyscanner );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size ,yyscan_t yyscanner );
void yy_delete_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void yy_flush_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
void yypop_buffer_state (yyscan_t yyscanner );

static void yyensure_buffer_stack (yyscan_t yyscanner );
static void yy_load_buffer_state (yyscan_t yyscanner );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file ,yyscan_t yyscanner );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER ,yyscanner)

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size ,yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str ,yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len ,yyscan_t yyscanner );

void *yyalloc (yy_size_t ,yyscan_t yyscanner );
void *yyrealloc (void *,yy_size_t ,yyscan_t yyscanner );
void yyfree (void * ,yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define yywrap(n) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state (yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  ,yyscan_t yyscanner);
static int yy_get_next_buffer (yyscan_t yyscanner );
static void yy_fatal_error (yyconst char msg[] ,yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;

#define YY_NUM_RULES 140
#define YY_END_OF_BUFFER 141
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[550] =
    {   0,
        0,    0,    0,    0,  141,  139,  137,  137,  139,  139,
      139,  139,  125,  139,  139,  139,  139,  129,  129,  129,
      129,  129,  129,  129,  129,  129,  129,  129,  129,  129,
      129,  129,  129,  129,  129,  129,  129,  129,  139,    2,
      140,    2,  137,  115,    0,  120,    0,    0,  122,  138,
        1,  121,  125,  130,  130,  119,  117,  116,  118,    0,
      131,  131,  131,  131,  129,  129,  129,  129,  129,    8,
      129,  129,  129,  129,  129,   17,  129,  129,  129,  129,
      129,  129,  129,  129,  129,  129,  129,  129,  129,  129,
      129,  129,  129,   47,   48,   54,  129,  129,  129,  129,

      129,  129,  129,  129,  129,  129,  129,  129,   72,  129,
      129,  129,  129,  129,  129,  129,  129,  129,  129,  129,
      129,  129,  102,  129,  129,  129,  129,  129,  129,  129,
      129,  129,    0,    0,    0,    3,    0,  123,  123,  138,
      121,    0,    0,  124,  132,  131,  131,  126,  131,    6,
      129,  129,    7,    9,  129,   12,  129,  129,  129,  129,
      129,  129,  129,  129,  129,  129,  129,  129,  129,  129,
      129,   32,  129,  129,  129,  129,  129,  129,   39,  129,
      129,  129,  129,  129,  129,  129,   52,  129,  129,  129,
      129,  129,  129,   61,  129,   63,   64,  129,  129,   68,

      129,  129,  129,  129,  129,  129,  129,  129,  129,  129,
      129,  129,  129,  129,  129,  129,  129,  129,   90,  129,
      129,  129,  129,   98,  129,  129,  129,  129,  129,  129,
      129,  129,  129,  129,  129,  129,  129,    0,    0,  135,
        0,  123,    0,  122,    0,  121,  124,    0,  132,  131,
      131,  129,  129,  129,  129,  129,  129,  129,   16,   18,
      129,  129,  129,  129,  129,  129,  129,  129,  129,   29,
      129,  129,   34,  129,  129,  129,  129,   40,  129,  129,
      129,  129,  129,  129,  129,   53,  129,   56,  129,   58,
      129,  129,   62,  129,  129,   69,  129,  129,   74,  129,

      129,  129,   79,   80,  129,  129,  129,  129,  129,  129,
      129,  129,  129,  129,  129,   93,  129,  129,  129,  129,
      129,  129,  129,  104,  129,  106,  129,  129,  129,  129,
      129,  129,  129,  129,    0,  136,  134,  122,  133,  131,
      131,    4,    5,  129,  129,   13,  129,  129,  129,   20,
      129,  129,  129,   25,  129,  129,  129,  129,  129,  129,
       35,   36,   37,   38,  129,  129,   43,  129,   49,  129,
      129,  129,   57,   59,   60,   65,   67,  129,  129,   73,
      129,  129,  129,  129,   84,  129,  129,  129,  129,  129,
      129,  129,  129,  129,  129,   95,  129,  129,   99,  129,

      129,  129,  129,  129,  129,  129,  129,  129,  113,  129,
      133,  128,  131,   10,  129,  129,   15,  129,  129,   22,
       23,   26,  129,   28,  129,  129,   33,  129,   42,  129,
      129,   46,   50,  129,  129,  129,  129,   70,   75,  129,
      129,  129,  129,  129,  129,  129,  129,   88,  129,  129,
      129,   94,   96,   97,  100,  129,  129,  129,  129,  108,
      109,  129,  129,  112,  114,  127,  129,   14,  129,  129,
      129,  129,  129,  129,  129,   44,  129,   51,  129,   66,
      129,   76,   77,  129,  129,  129,   83,   85,  129,   87,
      129,   92,  129,  101,  129,  129,  129,  129,  129,  129,

      129,  129,  129,  129,   30,   31,   41,  129,  129,   71,
       78,  129,  129,   86,  129,   91,  129,  105,  129,  129,
      111,  129,   19,   21,   24,   27,  129,   55,  129,  129,
      129,  129,  129,  110,   11,  129,  129,   82,  129,  129,
      129,  129,   81,  129,  103,  107,   45,   89,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    4,    1,    1,    1,    1,    1,    5,    1,
        1,    6,    7,    1,    8,    9,   10,   11,   11,   11,
       11,   12,   11,   13,   11,   11,   11,   14,    1,   15,
       16,   17,    1,   18,   19,   20,   21,   22,   23,   24,
       25,   26,   27,   28,   29,   30,   31,   32,   33,   34,
       35,   36,   37,   38,   39,   40,   41,   42,   43,   44,
        1,   45,    1,    1,   46,   47,   48,   49,   50,   51,

       52,   53,   54,   55,   56,   57,   58,   59,   60,   61,
       62,   63,   35,   64,   65,   66,   67,   68,   69,   70,
       71,   72,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[73] =
    {   0,
        1,    2,    2,    1,    1,    1,    1,    1,    3,    1,
        4,    4,    4,    1,    1,    1,    1,    5,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    1,    6,    7,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    6
    } ;

static yyconst flex_int16_t yy_base[568] =
    {   0,
        0,    0,   70,   71,  317, 1213,   76,   78,  294,   70,
       80,  302,   75,  258,   73,  247,   76,  124,   73,   76,
      124,    0,  163,   69,   66,  126,   71,  114,  181,  184,
      131,  176,  219,  221,  236,   89,   82,  263,  253, 1213,
     1213,  251,  108, 1213,  108, 1213,  136,  290,  283,    0,
     1213,  301,  314,  249,  321, 1213, 1213, 1213, 1213,    0,
        0,  109,  133,  145,    0,  147,  182,  135,  185,  189,
      175,  191,  306,  196,  191,    0,  219,  297,  308,  245,
      190,  240,  306,  281,  242,  319,  317,  306,  289,  320,
      321,  324,  319,    0,  339,  329,  330,  325,  351,  347,

      335,  362,  373,  366,  366,  350,  368,  362,  380,  391,
      370,  375,  419,  378,  385,  424,  381,  383,  423,  387,
      399,  385,    0,  426,  388,  413,  424,  436,  416,  428,
      445,  426,  107,  184,  451, 1213,  129,    0,  496,    0,
      499,  506,  465,  512,  217,    0,  460,    0,  459,    0,
      459,  478,    0,    0,  497,    0,  478,  485,  479,  498,
      499,  495,  504,  507,  507,  507,  521,  522,  519,  522,
      494,    0,  524,  513,  525,  513,  533,  518,    0,  522,
      535,  542,  525,  548,  556,  557,  561,  556,  555,  565,
      566,  563,  572,    0,  576,    0,    0,  559,  575,    0,

      569,  573,  578,  570,  578,  581,  585,  585,  588,  578,
      593,  591,  581,  596,  601,  614,  611,  605,  606,  604,
      627,  613,  620,    0,  622,  630,  622,  633,  634,  625,
      640,  622,  636,  632,  643,  635,  643,  172,  171, 1213,
      168,    0,  689,  692,  695,  698,  701,    0,  200,  658,
      666,  657,  660,  694,  689,  685,  695,  689,    0,    0,
      703,  696,  707,  696,  701,  692,  693,  712,  696,  699,
      709,  707,    0,  701,  717,  704,  717,    0,  710,  730,
      718,  721,  718,  728,  743,    0,  752,    0,  743,    0,
      737,  751,    0,  752,  746,    0,  753,  753,    0,  753,

      758,  761,    0,    0,  758,  757,  774,  775,  760,  778,
      777,  780,  785,  778,  780,    0,  779,  774,  779,  789,
      802,  807,  792,    0,  810,    0,  801,  797,  814,  819,
      814,  816,  820,  817,  132, 1213, 1213,  836,    0,  813,
      819,    0,    0,  826,  833,    0,  833,  820,  838,    0,
      824,  832,  830,    0,  842,  850,  852,  849,  845,  855,
        0,    0,    0,    0,  853,  853,  864,  862,    0,  851,
      868,  857,    0,    0,    0,  146,    0,  865,  865,    0,
      867,  870,  863,  879,    0,  870,  890,  882,  896,  895,
      884,  889,  891,  893,  904,    0,  894,  908,  898,  915,

      919,  920,  910,  919,  908,  926,  917,  913,    0,  920,
        0,    0,  917,    0,  918,  926,    0,  922,  934,    0,
      926,    0,  928,    0,  949,  951,    0,  941,    0,  933,
      956,    0,    0,  944,  955,  110,  940,    0,  949,  966,
      959,  967,  976,  973,  962,  976,  958,    0,  975,  973,
      982,    0,    0,    0,    0,  972,  989,  975,  988,    0,
        0,  986,  992,    0,    0,    0,  981,    0,  998,  989,
     1006, 1007, 1009,  997, 1001,    0, 1005,    0, 1007,    0,
     1019,    0,    0, 1014, 1023, 1029,    0,    0, 1023,    0,
     1010,    0, 1018,    0, 1018, 1034, 1022, 1041, 1029, 1045,

     1034, 1041, 1052, 1039,    0,    0,    0, 1047, 1048,    0,
        0, 1046, 1057,    0, 1070,    0, 1063,    0, 1054, 1058,
        0, 1059,    0,    0,    0,    0, 1078,    0, 1065, 1082,
     1086, 1074, 1087,    0,    0, 1092, 1089,    0, 1084, 1083,
     1095, 1083,    0, 1099,    0,    0,    0,    0, 1213, 1151,
     1158, 1164, 1168, 1170, 1173, 1176, 1179, 1182,  101, 1185,
     1188, 1191, 1195, 1199, 1202,   98, 1206
    } ;

static yyconst flex_int16_t yy_def[568] =
    {   0,
      549,    1,  550,  550,  549,  549,  549,  549,  549,  551,
      552,  549,  553,  549,  549,  549,  554,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  556,  549,
      549,  549,  549,  549,  551,  549,  551,  552,  557,  558,
      549,  549,  553,  553,  553,  549,  549,  549,  549,  559,
      560,  560,  560,  560,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,

      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  561,  562,  562,  549,  551,  563,  563,  558,
      549,  549,  549,  553,  564,  560,  560,  560,  560,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,

      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  565,  562,  549,
      562,  563,  549,  563,  549,  549,  549,  566,  564,  560,
      560,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,

      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  565,  549,  549,  549,  567,  560,
      560,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,

      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      567,  560,  560,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  560,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,

      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,    0,  549,
      549,  549,  549,  549,  549,  549,  549,  549,  549,  549,
      549,  549,  549,  549,  549,  549,  549
    } ;

static yyconst flex_int16_t yy_nxt[1286] =
    {   0,
        6,    7,    8,    9,   10,    6,    6,    6,   11,   12,
       13,   13,   13,   14,   15,    6,   16,   17,   18,   19,
       20,   21,   22,   23,   24,   25,   26,   27,   22,   28,
       29,   30,   31,   32,   22,   33,   34,   35,   36,   37,
       38,   22,   22,   22,    6,   22,   39,   18,   19,   20,
       21,   22,   23,   24,   25,   26,   27,   22,   28,   29,
       30,   31,   32,   33,   34,   35,   36,   37,   38,   22,
       22,   22,   41,   41,   46,   42,   42,   43,   43,   43,
       43,   48,   48,   52,   93,   53,   53,   53,   57,   58,
       49,   49,   49,   60,   77,   73,   62,   55,   91,   74,

      128,   78,   63,  339,   92,   75,  145,   97,   79,   43,
       43,   80,   46,   93,   47,   76,   64,  133,  133,  133,
      126,  480,  127,   77,   73,   62,   55,   91,   74,  128,
       78,   63,   92,   46,   75,   97,   98,   79,  549,   80,
       99,  147,   81,   76,   64,   66,   82,   94,   67,  126,
       83,  127,   47,   68,  148,   69,   84,   95,  436,   85,
       70,   71,   96,   72,  108,   98,  109,  149,  150,   99,
      147,   81,  152,   47,   66,   82,   94,   67,  336,   83,
      137,   86,   68,  148,   69,   84,   95,   85,   70,   71,
       96,   72,   87,  108,  109,   88,  149,  150,   89,  100,

      152,   90,  105,  101,  151,  110,  153,  102,  248,  154,
       86,  111,  155,  103,  337,  156,  106,  240,  336,  104,
      159,   87,  107,  160,   88,  248,   89,  168,  100,   90,
      240,  105,  101,  151,  110,  153,  102,  112,  154,  111,
      155,  113,  103,  116,  156,  106,  117,  104,  161,  159,
      107,  114,  160,  118,  121,  168,  115,  549,  119,  120,
      136,  122,   59,  133,  133,  133,  112,  167,  123,  169,
      113,  124,  116,   56,  174,  117,  170,  161,  125,  135,
      114,  129,  118,  121,  115,  130,  119,  120,  131,  132,
      122,   48,   48,   49,   49,   49,  167,  123,  169,  124,

      549,  549,  549,  174,  170,  139,  125,   51,  135,   44,
      129,  141,  141,  141,  130,  162,  549,  131,  132,  173,
      549,  180,   52,  142,   53,   53,   53,  143,  143,  549,
      157,  144,  144,  144,  139,  163,   55,  164,  165,  175,
      549,  179,  171,  158,  162,  172,  166,  173,  176,  177,
      180,  181,  142,  182,  549,  178,  183,  549,  184,  157,
      185,  188,  189,  163,  190,   55,  164,  165,  175,  179,
      171,  158,  195,  172,  166,  186,  187,  176,  177,  191,
      181,  192,  182,  178,  193,  183,  184,  200,  194,  185,
      188,  189,  190,  196,  197,  198,  199,  201,  549,  202,

      195,  203,  206,  186,  187,  207,  208,  214,  191,  204,
      192,  215,  193,  220,  221,  200,  194,  224,  225,  549,
      226,  229,  196,  197,  198,  199,  201,  202,  549,  205,
      203,  206,  549,  230,  207,  208,  214,  209,  204,  210,
      215,  222,  220,  221,  227,  231,  224,  225,  226,  211,
      229,  234,  212,  216,  235,  549,  213,  205,  223,  217,
      218,  219,  230,  237,  228,  232,  209,  236,  210,  549,
      222,  233,  241,  227,  231,  247,  247,  247,  211,  234,
      549,  212,  216,  235,  213,  251,  223,  217,  218,  219,
      252,  237,  228,  549,  232,  549,  236,  240,  250,  233,

      253,  241,  243,  243,  256,  258,  244,  244,  244,  141,
      141,  141,  245,  245,  251,  254,  246,  246,  246,  252,
      549,  142,  144,  144,  144,  257,  250,  259,  260,  253,
      261,  271,  255,  256,  258,  262,  263,  265,  266,  267,
      268,  269,  270,  272,  254,  264,  273,  274,  549,  275,
      142,  276,  278,  257,  277,  279,  259,  260,  261,  271,
      255,  280,  549,  281,  262,  263,  265,  266,  267,  268,
      269,  270,  272,  264,  282,  273,  274,  275,  283,  284,
      276,  278,  277,  285,  279,  287,  288,  289,  290,  291,
      280,  281,  292,  286,  293,  549,  294,  295,  296,  297,

      298,  299,  300,  282,  301,  302,  303,  283,  284,  304,
      305,  306,  285,  307,  287,  288,  289,  290,  291,  309,
      308,  292,  286,  293,  294,  310,  295,  296,  297,  298,
      299,  300,  311,  301,  302,  303,  312,  313,  304,  305,
      306,  314,  307,  315,  316,  317,  320,  309,  318,  308,
      319,  321,  322,  323,  310,  324,  326,  327,  328,  549,
      329,  311,  330,  331,  325,  312,  313,  332,  334,  314,
      333,  315,  316,  549,  317,  320,  318,  549,  319,  549,
      321,  322,  323,  549,  324,  326,  327,  328,  329,  340,
      341,  330,  331,  325,  342,  343,  332,  334,  333,  338,

      338,  338,  244,  244,  244,  246,  246,  246,  246,  246,
      246,  247,  247,  247,  344,  345,  346,  347,  340,  341,
      348,  349,  342,  343,  350,  351,  352,  353,  549,  354,
      355,  356,  549,  357,  358,  359,  360,  549,  361,  362,
      549,  363,  364,  344,  345,  346,  347,  365,  366,  348,
      349,  367,  368,  350,  351,  352,  353,  354,  355,  369,
      356,  357,  358,  370,  359,  360,  361,  371,  362,  363,
      372,  364,  373,  549,  374,  365,  375,  366,  376,  381,
      367,  368,  377,  378,  382,  379,  383,  369,  380,  384,
      385,  370,  386,  387,  549,  388,  371,  389,  390,  372,

      391,  373,  374,  392,  393,  375,  394,  376,  381,  395,
      377,  396,  378,  382,  379,  383,  380,  397,  384,  385,
      398,  386,  387,  388,  399,  400,  389,  390,  401,  391,
      402,  403,  392,  393,  404,  394,  405,  406,  395,  396,
      407,  408,  409,  410,  413,  397,  338,  338,  338,  398,
      412,  414,  415,  399,  400,  416,  401,  417,  418,  402,
      403,  419,  404,  420,  422,  405,  406,  421,  423,  407,
      408,  409,  410,  413,  424,  425,  426,  427,  412,  428,
      414,  415,  429,  430,  416,  417,  432,  418,  433,  419,
      434,  437,  420,  422,  435,  421,  438,  423,  439,  440,

      549,  441,  442,  424,  425,  426,  427,  443,  428,  431,
      444,  429,  430,  445,  446,  432,  433,  447,  449,  434,
      437,  448,  435,  450,  451,  438,  452,  439,  440,  441,
      453,  442,  454,  549,  455,  443,  456,  457,  458,  444,
      459,  460,  445,  446,  461,  462,  447,  449,  463,  448,
      464,  465,  450,  451,  466,  452,  467,  468,  453,  469,
      470,  454,  455,  471,  472,  456,  457,  458,  473,  459,
      460,  474,  461,  475,  462,  476,  477,  463,  464,  478,
      465,  479,  466,  481,  467,  482,  468,  469,  483,  470,
      484,  471,  472,  485,  486,  487,  489,  473,  488,  490,

      474,  491,  475,  476,  492,  477,  493,  478,  494,  495,
      479,  481,  496,  482,  497,  498,  499,  483,  500,  484,
      501,  502,  485,  486,  487,  489,  488,  490,  503,  504,
      491,  505,  507,  492,  506,  493,  494,  508,  495,  509,
      496,  510,  511,  497,  498,  499,  500,  512,  513,  501,
      502,  514,  549,  515,  516,  517,  518,  503,  504,  519,
      505,  507,  506,  520,  549,  521,  508,  522,  509,  523,
      510,  511,  524,  525,  549,  526,  512,  513,  527,  528,
      514,  515,  516,  517,  529,  518,  530,  519,  531,  532,
      549,  533,  520,  521,  534,  535,  522,  523,  536,  549,

      537,  524,  525,  526,  538,  539,  540,  527,  528,  541,
      542,  543,  529,  544,  545,  530,  546,  531,  532,  533,
      547,  548,  534,  535,  549,  549,  549,  536,  537,  549,
      549,  549,  549,  538,  539,  540,  549,  549,  541,  542,
      543,  549,  544,  545,  549,  546,  549,  549,  547,  549,
      548,   40,   40,   40,   40,   40,   40,   40,   45,   45,
       45,   45,   45,   45,   45,   50,  549,   50,  549,   50,
       54,   54,  549,   54,   61,   61,   65,  549,   65,  134,
      549,  134,  138,  549,  138,  140,  549,  140,  146,  549,
      146,  238,  549,  238,  239,  549,  239,  239,  242,  549,

      242,  249,  249,  549,  249,  335,  549,  335,  335,  411,
      549,  411,    5,  549,  549,  549,  549,  549,  549,  549,
      549,  549,  549,  549,  549,  549,  549,  549,  549,  549,
      549,  549,  549,  549,  549,  549,  549,  549,  549,  549,
      549,  549,  549,  549,  549,  549,  549,  549,  549,  549,
      549,  549,  549,  549,  549,  549,  549,  549,  549,  549,
      549,  549,  549,  549,  549,  549,  549,  549,  549,  549,
      549,  549,  549,  549,  549,  549,  549,  549,  549,  549,
      549,  549,  549,  549,  549
    } ;

static yyconst flex_int16_t yy_chk[1286] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    3,    4,   10,    3,    4,    7,    7,    8,
        8,   11,   11,   13,   25,   13,   13,   13,   15,   15,
       11,   11,   11,   17,   20,   19,   17,   13,   24,   19,

       37,   20,   17,  566,   24,   19,  559,   27,   20,   43,
       43,   20,   45,   25,   10,   19,   17,  133,  133,  133,
       36,  436,   36,   20,   19,   17,   13,   24,   19,   37,
       20,   17,   24,  137,   19,   27,   28,   20,   47,   20,
       28,   62,   21,   19,   17,   18,   21,   26,   18,   36,
       21,   36,   45,   18,   63,   18,   21,   26,  376,   21,
       18,   18,   26,   18,   31,   28,   31,   64,   66,   28,
       62,   21,   68,  137,   18,   21,   26,   18,  335,   21,
       47,   23,   18,   63,   18,   21,   26,   21,   18,   18,
       26,   18,   23,   31,   31,   23,   64,   66,   23,   29,

       68,   23,   30,   29,   67,   32,   69,   29,  249,   70,
       23,   32,   71,   29,  241,   72,   30,  239,  238,   29,
       74,   23,   30,   75,   23,  145,   23,   81,   29,   23,
      134,   30,   29,   67,   32,   69,   29,   33,   70,   32,
       71,   33,   29,   34,   72,   30,   34,   29,   77,   74,
       30,   33,   75,   34,   35,   81,   33,   54,   34,   34,
       42,   35,   16,   39,   39,   39,   33,   80,   35,   82,
       33,   35,   34,   14,   85,   34,   82,   77,   35,   39,
       33,   38,   34,   35,   33,   38,   34,   34,   38,   38,
       35,   48,   48,   49,   49,   49,   80,   35,   82,   35,

       48,   48,   48,   85,   82,   49,   35,   12,   39,    9,
       38,   52,   52,   52,   38,   78,    5,   38,   38,   84,
        0,   89,   53,   52,   53,   53,   53,   55,   55,   55,
       73,   55,   55,   55,   49,   78,   53,   79,   79,   86,
        0,   88,   83,   73,   78,   83,   79,   84,   86,   87,
       89,   90,   52,   91,    0,   87,   92,    0,   93,   73,
       95,   96,   97,   78,   98,   53,   79,   79,   86,   88,
       83,   73,  101,   83,   79,   95,   95,   86,   87,   99,
       90,   99,   91,   87,  100,   92,   93,  106,  100,   95,
       96,   97,   98,  102,  103,  104,  105,  107,    0,  108,

      101,  109,  111,   95,   95,  112,  112,  114,   99,  110,
       99,  115,  100,  117,  118,  106,  100,  120,  121,    0,
      122,  125,  102,  103,  104,  105,  107,  108,    0,  110,
      109,  111,    0,  126,  112,  112,  114,  113,  110,  113,
      115,  119,  117,  118,  124,  127,  120,  121,  122,  113,
      125,  129,  113,  116,  130,    0,  113,  110,  119,  116,
      116,  116,  126,  132,  124,  128,  113,  131,  113,    0,
      119,  128,  135,  124,  127,  143,  143,  143,  113,  129,
        0,  113,  116,  130,  113,  149,  119,  116,  116,  116,
      151,  132,  124,    0,  128,    0,  131,  135,  147,  128,

      152,  135,  139,  139,  157,  159,  139,  139,  139,  141,
      141,  141,  142,  142,  149,  155,  142,  142,  142,  151,
      144,  141,  144,  144,  144,  158,  147,  160,  161,  152,
      162,  171,  155,  157,  159,  163,  164,  165,  166,  167,
      168,  169,  170,  173,  155,  164,  174,  175,    0,  176,
      141,  177,  180,  158,  178,  181,  160,  161,  162,  171,
      155,  182,    0,  183,  163,  164,  165,  166,  167,  168,
      169,  170,  173,  164,  184,  174,  175,  176,  185,  186,
      177,  180,  178,  187,  181,  188,  189,  190,  191,  192,
      182,  183,  193,  187,  195,    0,  198,  199,  201,  202,

      203,  204,  205,  184,  206,  207,  208,  185,  186,  209,
      210,  211,  187,  212,  188,  189,  190,  191,  192,  213,
      212,  193,  187,  195,  198,  214,  199,  201,  202,  203,
      204,  205,  215,  206,  207,  208,  216,  217,  209,  210,
      211,  218,  212,  219,  220,  221,  223,  213,  222,  212,
      222,  225,  226,  227,  214,  228,  229,  230,  231,    0,
      232,  215,  233,  234,  228,  216,  217,  235,  237,  218,
      236,  219,  220,    0,  221,  223,  222,    0,  222,    0,
      225,  226,  227,    0,  228,  229,  230,  231,  232,  250,
      251,  233,  234,  228,  252,  253,  235,  237,  236,  243,

      243,  243,  244,  244,  244,  245,  245,  245,  246,  246,
      246,  247,  247,  247,  254,  255,  256,  257,  250,  251,
      258,  261,  252,  253,  262,  263,  264,  265,    0,  266,
      267,  268,    0,  269,  270,  271,  272,    0,  274,  275,
        0,  276,  277,  254,  255,  256,  257,  279,  280,  258,
      261,  281,  282,  262,  263,  264,  265,  266,  267,  283,
      268,  269,  270,  284,  271,  272,  274,  285,  275,  276,
      287,  277,  289,    0,  291,  279,  292,  280,  294,  300,
      281,  282,  295,  297,  301,  297,  302,  283,  298,  305,
      306,  284,  307,  308,    0,  309,  285,  310,  311,  287,

      312,  289,  291,  313,  314,  292,  315,  294,  300,  317,
      295,  318,  297,  301,  297,  302,  298,  319,  305,  306,
      320,  307,  308,  309,  321,  322,  310,  311,  323,  312,
      325,  327,  313,  314,  328,  315,  329,  330,  317,  318,
      331,  332,  333,  334,  341,  319,  338,  338,  338,  320,
      340,  344,  345,  321,  322,  347,  323,  348,  349,  325,
      327,  351,  328,  352,  355,  329,  330,  353,  356,  331,
      332,  333,  334,  341,  357,  358,  359,  360,  340,  365,
      344,  345,  366,  367,  347,  348,  368,  349,  370,  351,
      371,  378,  352,  355,  372,  353,  379,  356,  381,  382,

        0,  383,  384,  357,  358,  359,  360,  386,  365,  367,
      387,  366,  367,  388,  389,  368,  370,  390,  392,  371,
      378,  391,  372,  393,  394,  379,  395,  381,  382,  383,
      397,  384,  398,    0,  399,  386,  400,  401,  402,  387,
      403,  404,  388,  389,  405,  406,  390,  392,  407,  391,
      408,  410,  393,  394,  413,  395,  415,  416,  397,  418,
      419,  398,  399,  421,  423,  400,  401,  402,  425,  403,
      404,  426,  405,  428,  406,  430,  431,  407,  408,  434,
      410,  435,  413,  437,  415,  439,  416,  418,  440,  419,
      441,  421,  423,  442,  443,  444,  446,  425,  445,  447,

      426,  449,  428,  430,  450,  431,  451,  434,  456,  457,
      435,  437,  458,  439,  459,  462,  463,  440,  467,  441,
      469,  470,  442,  443,  444,  446,  445,  447,  471,  472,
      449,  473,  475,  450,  474,  451,  456,  477,  457,  479,
      458,  481,  484,  459,  462,  463,  467,  485,  486,  469,
      470,  489,    0,  491,  493,  495,  496,  471,  472,  497,
      473,  475,  474,  498,    0,  499,  477,  500,  479,  501,
      481,  484,  502,  503,    0,  504,  485,  486,  508,  509,
      489,  491,  493,  495,  512,  496,  513,  497,  515,  517,
        0,  519,  498,  499,  520,  522,  500,  501,  527,    0,

      529,  502,  503,  504,  530,  531,  532,  508,  509,  533,
      536,  537,  512,  539,  540,  513,  541,  515,  517,  519,
      542,  544,  520,  522,    0,    0,    0,  527,  529,    0,
        0,    0,    0,  530,  531,  532,    0,    0,  533,  536,
      537,    0,  539,  540,    0,  541,    0,    0,  542,    0,
      544,  550,  550,  550,  550,  550,  550,  550,  551,  551,
      551,  551,  551,  551,  551,  552,    0,  552,    0,  552,
      553,  553,    0,  553,  554,  554,  555,    0,  555,  556,
        0,  556,  557,    0,  557,  558,    0,  558,  560,    0,
      560,  561,    0,  561,  562,    0,  562,  562,  563,    0,

      563,  564,  564,    0,  564,  565,    0,  565,  565,  567,
        0,  567,  549,  549,  549,  549,  549,  549,  549,  549,
      549,  549,  549,  549,  549,  549,  549,  549,  549,  549,
      549,  549,  549,  549,  549,  549,  549,  549,  549,  549,
      549,  549,  549,  549,  549,  549,  549,  549,  549,  549,
      549,  549,  549,  549,  549,  549,  549,  549,  549,  549,
      549,  549,  549,  549,  549,  549,  549,  549,  549,  549,
      549,  549,  549,  549,  549,  549,  549,  549,  549,  549,
      549,  549,  549,  549,  549
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "sphinxql.l"
#line 2 "sphinxql.l"
#include "yysphinxql.h"

#if USE_WINDOWS
#pragma warning(push,1)
#endif

// warning, lexer generator dependent!
// this macro relies on that in flex yytext points to the actual location in the buffer
#define YYSTOREBOUNDS \
	{ \
		lvalp->m_iStart = yytext - pParser->m_pBuf; \
		lvalp->m_iEnd = lvalp->m_iStart + yyleng; \
		pParser->m_pLastTokenStart = yytext; \
	}


#line 926 "llsphinxql.c"

#define INITIAL 0
#define ccomment 1

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    }; /* end struct yyguts_t */

static int yy_init_globals (yyscan_t yyscanner );

int yylex_init (yyscan_t* scanner);

int yylex_init_extra (YY_EXTRA_TYPE user_defined,yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (yyscan_t yyscanner );

int yyget_debug (yyscan_t yyscanner );

void yyset_debug (int debug_flag ,yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra (yyscan_t yyscanner );

void yyset_extra (YY_EXTRA_TYPE user_defined ,yyscan_t yyscanner );

FILE *yyget_in (yyscan_t yyscanner );

void yyset_in  (FILE * in_str ,yyscan_t yyscanner );

FILE *yyget_out (yyscan_t yyscanner );

void yyset_out  (FILE * out_str ,yyscan_t yyscanner );

int yyget_leng (yyscan_t yyscanner );

char *yyget_text (yyscan_t yyscanner );

int yyget_lineno (yyscan_t yyscanner );

void yyset_lineno (int line_number ,yyscan_t yyscanner );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (yyscan_t yyscanner );
#else
extern int yywrap (yyscan_t yyscanner );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int ,yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * ,yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (yyscan_t yyscanner );
#else
static int input (yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (yyscan_t yyscanner);

#define YY_DECL int yylex (yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

#line 31 "sphinxql.l"


#line 1154 "llsphinxql.c"

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
		}

		yy_load_buffer_state(yyscanner );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				yyg->yy_last_accepting_state = yy_current_state;
				yyg->yy_last_accepting_cpos = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 550 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1213 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = yyg->yy_hold_char;
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 33 "sphinxql.l"
{ BEGIN(ccomment); }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 34 "sphinxql.l"
{ }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 35 "sphinxql.l"
{ BEGIN(INITIAL); }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 37 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_AGENT; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 38 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ALTER; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 39 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ADD; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 40 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_AND; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 41 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_AS; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 42 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ASC; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 43 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ATTACH; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 44 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ATTRIBUTES; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 45 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_AVG; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 46 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_BEGIN; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 47 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_BETWEEN; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 48 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_BIGINT; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 49 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_BOOL; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 50 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_BY; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 51 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_CALL; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 52 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_CHARACTER; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 53 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_CHUNK; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 54 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_COLLATION; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 55 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_COLUMN; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 56 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_COMMIT; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 57 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_COMMITTED; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 58 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_COUNT; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 59 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_CREATE; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 60 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DATABASES; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 61 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DELETE; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 62 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DESC; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 63 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DESCRIBE; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 64 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DISTINCT; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 65 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DIV; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 66 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DOUBLE; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 67 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DROP; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 68 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_FACET; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 69 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_FALSE; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 70 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_FLOAT; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 71 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_FLUSH; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 72 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_FOR; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 73 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_FROM; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 74 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_FUNCTION; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 75 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_GLOBAL; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 76 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_GROUP; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 77 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_GROUPBY; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 78 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_GROUP_CONCAT; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 79 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_HAVING; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 80 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ID; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 81 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_IN; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 82 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_INDEX; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 83 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_INSERT; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 84 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_INTEGER; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 85 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_INT; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 86 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_INTO; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 87 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_IS; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 88 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ISOLATION; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 89 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_JSON; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 90 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_LEVEL; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 91 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_LIKE; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 92 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_LIMIT; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 93 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_MATCH; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 94 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_MAX; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 95 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_META; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 96 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_MIN; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 97 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_MOD; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 98 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_MULTI; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 99 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_MULTI64; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 100 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_NAMES; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 101 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_NOT; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 102 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_NULL; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 103 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_OPTION; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 104 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_OPTIMIZE; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 105 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_OR; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 106 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ORDER; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 107 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_PLAN; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 108 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_PLUGIN; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 109 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_PLUGINS; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 110 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_PROFILE; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 111 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_RAMCHUNK; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 112 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_RAND; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 113 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_READ; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 114 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_RECONFIGURE; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 115 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_REPEATABLE; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 116 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_REPLACE; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 117 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_REMAP; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 118 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_RETURNS; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 119 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ROLLBACK; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 120 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_RTINDEX; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 121 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SELECT; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 122 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SERIALIZABLE; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 123 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SET; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 124 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SETTINGS; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 125 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SESSION; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 126 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SHOW; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 127 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SONAME; }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 128 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_START; }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 129 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_STATUS; }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 130 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_STRING; }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 131 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SUM; }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 132 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_TABLE; }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 133 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_TABLES; }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 134 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_THREADS; }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 135 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_TO; }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 136 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_TRANSACTION; }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 137 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_TRUE; }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 138 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_TRUNCATE; }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 139 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_TYPE; }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 140 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_UNCOMMITTED; }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 141 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_UPDATE; }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 142 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_VALUES; }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 143 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_VARIABLES; }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 144 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_WARNINGS; }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 145 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_WEIGHT; }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 146 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_WHERE; }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 147 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_WITHIN; }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 149 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_NE; }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 150 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_NE; }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 151 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_LTE; }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 152 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_GTE; }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 153 "sphinxql.l"
{ YYSTOREBOUNDS; return '='; }
	YY_BREAK
case 120:
/* rule 120 can match eol */
YY_RULE_SETUP
#line 155 "sphinxql.l"
{ YYSTOREBOUNDS; pParser->m_pLastTokenStart = yytext; lvalp->m_iValue = ( (SphAttr_t)lvalp->m_iStart<<32 ) | ( lvalp->m_iEnd-lvalp->m_iStart ); return TOK_QUOTED_STRING; }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 157 "sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_fValue = (float)strtod ( yytext, NULL ); return TOK_CONST_FLOAT; }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 158 "sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_fValue = (float)strtod ( yytext, NULL ); return TOK_DOT_NUMBER; }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 159 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SUBKEY; }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 160 "sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_fValue = (float)strtod ( yytext, NULL ); return TOK_CONST_FLOAT; }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 161 "sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_iValue = (int64_t)strtoull ( yytext, NULL, 10 ); return TOK_CONST_INT; }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 163 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ATIDENT; }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 164 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ATIDENT; }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 165 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ATIDENT; }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 166 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_IDENT; }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 167 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_BAD_NUMERIC; }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 168 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_USERVAR; }
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 169 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SYSVAR; }
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 170 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SYSVAR; }
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 171 "sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_iStart++; lvalp->m_iEnd--; return TOK_ID; }
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 172 "sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_iStart++; lvalp->m_iEnd--; return TOK_IDENT; }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 173 "sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_iStart++; lvalp->m_iEnd--; return TOK_IDENT; } // allow `123xyz` column names
	YY_BREAK
case 137:
/* rule 137 can match eol */
YY_RULE_SETUP
#line 175 "sphinxql.l"
{ ; }
	YY_BREAK
case 138:
/* rule 138 can match eol */
YY_RULE_SETUP
#line 176 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SUBKEY; }
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 177 "sphinxql.l"
{ YYSTOREBOUNDS; return yytext[0]; }
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 179 "sphinxql.l"
ECHO;
	YY_BREAK
#line 1940 "llsphinxql.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(ccomment):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_c_buf_p;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap(yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = yyg->yytext_ptr;
	register int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2 ,yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  ,yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) (yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size ,yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			yyg->yy_last_accepting_state = yy_current_state;
			yyg->yy_last_accepting_cpos = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 550 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	register int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
	register char *yy_cp = yyg->yy_c_buf_p;

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		yyg->yy_last_accepting_state = yy_current_state;
		yyg->yy_last_accepting_cpos = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 550 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 549);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = yyg->yy_c_buf_p - yyg->yytext_ptr;
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin ,yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(yyscanner ) )
						return EOF;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file ,yyscanner);
	yy_load_buffer_state(yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2 ,yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file ,yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf ,yyscanner );

	yyfree((void *) b ,yyscanner );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer(b ,yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER ,yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	int num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b ,yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes(yystr,strlen(yystr) ,yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n ,yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n ,yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg , yyscan_t yyscanner)
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param line_number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           yy_fatal_error( "yyset_lineno called with no buffer" , yyscanner); 
    
    yylineno = line_number;
}

/** Set the current column.
 * @param line_number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           yy_fatal_error( "yyset_column called with no buffer" , yyscanner); 
    
    yycolumn = column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = in_str ;
}

void yyset_out (FILE *  out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = bdebug ;
}

/* Accessor methods for yylval and yylloc */

/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */

int yylex_init(yyscan_t* ptr_yy_globals)

{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */

int yylex_init_extra(YY_EXTRA_TYPE yy_user_defined,yyscan_t* ptr_yy_globals )

{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }
	
    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );
	
    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }
    
    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));
    
    yyset_extra (yy_user_defined, *ptr_yy_globals);
    
    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = 0;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = (char *) 0;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER ,yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack ,yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree(yyg->yy_start_stack ,yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n , yyscan_t yyscanner)
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s , yyscan_t yyscanner)
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr , yyscan_t yyscanner)
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 179 "sphinxql.l"



// warning, lexer generator dependent!
// flex inserts trailing zero as needed into the buffer when lexing
// but we need that rolled back when doing error reporting from yyerror
void yylex_unhold ( yyscan_t yyscanner )
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( YY_CURRENT_BUFFER )
	{
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
	}
}

#if USE_WINDOWS
#pragma warning(pop)
#endif

